window.onload = () => {
	let overview = {
		checks: document.getElementById("overview_checks"),
		entrances: document.getElementById("overview_entrances"),
		summary: document.getElementById("summary"),
	};
	let current_scene = {
		name: document.getElementById("current_scene_text"),
		checks: {
			title: document.getElementById("current_scene_checks_title"),
			list: document.getElementById("current_scene_checks_list"),
		},
		entrances: {
			title: document.getElementById("current_scene_entrances_title"),
			list: document.getElementById("current_scene_entrances_list"),
			mapped: document.getElementById("current_scene_entrances_mapped"),
		},
	};
	let line_elem = document
		.getElementById("current_scene_checks_list")
		.firstElementChild.cloneNode(true);
	let mapped_line_elem = document
		.getElementById("current_scene_entrances_mapped")
		.firstElementChild.cloneNode(true);
	let summary_element = document
		.getElementById("summary")
		.firstElementChild.cloneNode(true);
	summary_element.classList.forEach((class_name) => {
		if (class_name == "bg-green-900") {
			summary_element.classList.remove(class_name);
		} else if (class_name == "bg-yellow-900") {
			summary_element.classList.remove(class_name);
		} else if (class_name == "bg-blue-900") {
			summary_element.classList.remove(class_name);
		}
	});
	const refresh_interval = setInterval(
		refresh_elements,
		500,
		overview,
		current_scene,
		line_elem,
		mapped_line_elem,
		summary_element
	);
};

async function refresh_elements(
	overview,
	current_scene,
	line_elem,
	mapped_line_elem,
	summary_element
) {
	fetch("http://localhost:8000/spoiler")
		.then((response) => response.json())
		.then((data) => {
			const response_object = JSON.parse(JSON.stringify(data));
			const overview_checks_undiscovered =
				response_object.Totals.Checks.Undiscovered;
			const overview_checks_total = response_object.Totals.Checks.Total;
			const overview_entrances_undiscovered =
				response_object.Totals.Entrances.Undiscovered;
			const overview_entrances_total = response_object.Totals.Entrances.Total;
			const current_scene_name = response_object.Current.Scene;
			const current_scene_checks_undiscovered =
				response_object.Scenes[current_scene_name].Totals.Checks.Undiscovered;
			const current_scene_checks_total =
				response_object.Scenes[current_scene_name].Totals.Checks.Total;
			const current_scene_entrances_undiscovered =
				response_object.Scenes[current_scene_name].Totals.Entrances
					.Undiscovered;
			const current_scene_entrances_total =
				response_object.Scenes[current_scene_name].Totals.Entrances.Total;
			const current_scene_checks_list =
				response_object.Scenes[current_scene_name].Checks;
			const current_scene_entrances_list =
				response_object.Scenes[current_scene_name].Entrances;
			const all_scenes = response_object.Scenes;
			overview.checks.textContent = `Checks: ${overview_checks_undiscovered}/${overview_checks_total}`;
			overview.entrances.textContent = `Entrances: ${overview_entrances_undiscovered}/${overview_entrances_total}`;
			current_scene.name.textContent = current_scene_name;
			current_scene.checks.title.textContent = `Checks: ${current_scene_checks_undiscovered}/${current_scene_checks_total}`;
			current_scene.entrances.title.textContent = `Entrances: ${current_scene_entrances_undiscovered}/${current_scene_entrances_total}`;
			current_scene.checks.list.innerHTML = "";
			current_scene.entrances.list.innerHTML = "";
			current_scene.entrances.mapped.innerHTML = "";
			overview.summary.innerHTML = "";
			Object.keys(current_scene_checks_list).forEach((check) => {
				if (!current_scene_checks_list[check]) {
					line_elem.textContent = `❌ ${check}`;
					current_scene.checks.list.appendChild(line_elem.cloneNode(true));
				}
			});
			Object.keys(current_scene_entrances_list).forEach((entrances) => {
				if (current_scene_entrances_list[entrances] == "") {
					line_elem.textContent = `❌ ${entrances}`;
					current_scene.entrances.list.appendChild(line_elem.cloneNode(true));
				} else {
					mapped_line_elem.textContent = `✔️ ${entrances} -> ${current_scene_entrances_list[entrances]}`;
					current_scene.entrances.mapped.appendChild(
						mapped_line_elem.cloneNode(true)
					);
				}
			});
			let scene_div = document.createElement("div");
			let checks_div = document.createElement("div");
			let entrances_div = document.createElement("div");
			let scene_checks_undiscovered = 0;
			let scene_checks_total = 0;
			let scene_entrances_undiscovered = 0;
			let scene_entrances_total = 0;
			Object.keys(all_scenes).forEach((scene) => {
				summary_element.innerHTML = "";
				scene_div.textContent = scene;
				scene_checks_undiscovered =
					all_scenes[scene]["Totals"]["Checks"]["Undiscovered"];
				scene_checks_total = all_scenes[scene]["Totals"]["Checks"]["Total"];
				scene_entrances_undiscovered =
					all_scenes[scene]["Totals"]["Entrances"]["Undiscovered"];
				scene_entrances_total =
					all_scenes[scene]["Totals"]["Entrances"]["Total"];
				if (scene_entrances_total <= 0) {
					return;
				}
				if (scene == current_scene.name.textContent) {
					return;
				}
				checks_div.textContent = `Checks: ${scene_checks_undiscovered}/${scene_checks_total}`;
				entrances_div.textContent = `Entrances: ${scene_entrances_undiscovered}/${scene_entrances_total}`;
				if (scene_checks_undiscovered > 0 && scene_entrances_undiscovered > 0) {
					if (scene_entrances_undiscovered == scene_entrances_total) {
						summary_element.classList.add("bg-red-900");
						summary_element.classList.remove(
							"bg-green-900",
							"bg-yellow-900",
							"bg-blue-900"
						);
					} else {
						summary_element.classList.add("bg-green-900");
						summary_element.classList.remove(
							"bg-blue-900",
							"bg-yellow-900",
							"bg-red-900"
						);
					}
				} else if (scene_checks_undiscovered > 0) {
					summary_element.classList.add("bg-yellow-900");
					summary_element.classList.remove(
						"bg-blue-900",
						"bg-green-900",
						"bg-red-900"
					);
				} else if (scene_entrances_undiscovered > 0) {
					summary_element.classList.add("bg-blue-900");
					summary_element.classList.remove(
						"bg-green-900",
						"bg-yellow-900",
						"bg-red-900"
					);
				} else {
					summary_element.classList.remove(
						"bg-green-900",
						"bg-yellow-900",
						"bg-blue-900",
						"bg-red-900"
					);
				}
				summary_element.appendChild(scene_div.cloneNode(true));
				summary_element.appendChild(checks_div.cloneNode(true));
				summary_element.appendChild(entrances_div.cloneNode(true));
				overview.summary.appendChild(summary_element.cloneNode(true));
			});
		})
		.catch((err) => {
			console.log(err);
		});
}

function log_elements() {
	console.log(overview.checks.textContent);
	console.log(overview.entrances.textContent);
	console.log(current_scene.name.textContent);
	console.log(current_scene.checks.title.textContent);
	for (i in current_scene.checks.list.children) {
		if (current_scene.checks.list.children[i].textContent) {
			console.log(current_scene.checks.list.children[i].textContent);
		}
	}
	console.log(current_scene.entrances.title.textContent);
	for (i in current_scene.entrances.list.children) {
		if (current_scene.entrances.list.children[i].textContent) {
			console.log(current_scene.entrances.list.children[i].textContent);
		}
	}
	for (i in current_scene.entrances.mapped.children) {
		if (current_scene.entrances.mapped.children[i].textContent) {
			console.log(current_scene.entrances.mapped.children[i].textContent);
		}
	}
}
